@@ -36,7 +36,13 @@ class Channel:
                 "mid": member_id,
             }
             await self.__sendPacket("KICKMEM", data)
-
+    async def hide(self, id):
+        if self.li:
+            data = {
+                "logId": id,
+                "chatId": self.id,
+            }
+            await self.__sendPacket("DELETEMSG", data)
     # async def get_linkinfo(self):
     #     return await self.__sendPacket("INFOLINK", {"lis": [self.li]})
 
