@@ -120,10 +120,10 @@ class HTTP:
                 data={
                     "attachment_type": dataType,
                     "user_id": userId,
-                },
-                files={
                     "attachment": data,
-                },) as resp:
+                },
+                # files={},
+                ) as resp:
                 path = (await resp.content()).decode()
 
         key = path.replace("/talkm", "")
